"""
COPYRIGHT BENNY 2021

ALL RIGHTS RESERVED TO THE 
DEVELOPER OF THIS PROJECT.
"""

import random

from .wrapper import Wrapper
from .utils import TokenInfo, Logger

from .channel2 import Channel
from .message2 import Message
from .embed import Embed
from .user import User
from .userinfo import UserInfo
from .messages import Messages
from .account import Account

__baseurl = "https://discord.com/api/"
__usertoken = ""
__baseheaders = {"Authorization": __usertoken, "Content-Type": "application/json"}
__logging = False
__userAgents = ["Mozilla/5.0 (Windows NT 6.2;en-US) AppleWebKit/537.32.36 (KHTML, live Gecko) Chrome/56.0.3075.83 Safari/537.32", "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.1", "Mozilla/5.0 (Windows NT 8.0; WOW64) AppleWebKit/536.24 (KHTML, like Gecko) Chrome/32.0.2019.89 Safari/536.24", "Mozilla/5.0 (Windows NT 5.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.41 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3058.0 Safari/537.36", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3258.0 Safari/537.36", "Mozilla/5.0 (Windows NT 5.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36", "Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/49.0.2599.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.35 (KHTML, like Gecko) Chrome/27.0.1453.0 Safari/537.35", "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.139 Safari/537.36", "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/6.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/42.0.0.9757 Safari/537.36", "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.1", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3258.0 Safari/537.36", "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/6.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.1", "Mozilla/5.0 (Windows NT 5.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2151.2 Safari/537.36", "Mozilla/5.0 (Windows NT 5.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1204.0 Safari/537.1", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) HeadlessChrome/67.0.3387.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/42.0.0.9757 Safari/537.36", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3359.181 Safari/537.36", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.81 Safari/537.36", "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3251.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/538 (KHTML, like Gecko) Chrome/36 Safari/538", "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.18 Safari/535.1", "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/533.3 (KHTML, like Gecko) Chrome/5.0.355.0 Safari/533.3", "Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US) AppleWebKit/532.0 (KHTML, like Gecko) Chrome/3.0.195.4 Safari/532.0", "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.35 (KHTML, like Gecko) Chrome/27.0.1453.0 Safari/537.35", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3359.181 Safari/537.36", "Mozilla/5.0 (Windows NT 10.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/45.0.2454.101 Safari/537.36", "Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3057.0 Safari/537.36", "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.14 (KHTML, like Gecko) Chrome/46.0.2490.86 Safari/537.14", "Mozilla/5.0 (Windows NT 6.4; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36 TC2", "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3058.0 Safari/537.36", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3258.0 Safari/537.36", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/48.0.2531.0 Safari/537.36", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.81 Safari/537.36", "Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36,gzip(gfe)", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2264.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.29 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.150 Safari/537.36", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.45 Safari/537.36", "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.14 (KHTML, like Gecko) Chrome/46.0.2490.86 Safari/537.14", "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2714.0 Safari/537.36", "24.0.1284.0.0 (Windows NT 5.1) AppleWebKit/534.0 (KHTML, like Gecko) Chrome/24.0.1284.0.3.742.3 Safari/534.3", "Mozilla/5.0 (X11; Ubuntu; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1864.6 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Chrome/36.0.1985.125 CrossBrowser/36.0.1985.138 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.102 Safari/537.36 Avast/70.0.917.102", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1615.0 Safari/537.36", "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.14 (KHTML, like Gecko) Chrome/46.0.2490.86 Safari/537.14", "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/6.0 Safari/537.36", "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3608.0 Safari/537.36", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.81 Safari/537.36", "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3251.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/54.2.133 Chrome/48.2.2564.133 Safari/537.36", "24.0.1284.0.0 (Windows NT 5.1) AppleWebKit/534.0 (KHTML, like Gecko) Chrome/24.0.1284.0.3.742.3 Safari/534.3", "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/54.2.133 Chrome/48.2.2564.133 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/54.2.133 Chrome/48.2.2564.133 Safari/537.36", "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.18 Safari/535.1", "Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/45.0.2427.7 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/44.0.2403.61 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Chrome/36.0.1985.125 CrossBrowser/36.0.1985.138 Safari/537.36", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.45 Safari/537.36", "Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/530.6 (KHTML, like Gecko) Chrome/2.0.174.0 Safari/530.6", "Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.29 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.104 Safari/537.36", "24.0.1284.0.0 (Windows NT 5.1) AppleWebKit/534.0 (KHTML, like Gecko) Chrome/24.0.1284.0.3.742.3 Safari/534.3", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko; Google Web Preview) Chrome/27.0.1453 Safari/537.36,gzip(gfe)", "Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.29 Safari/537.36", "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.45 (KHTML, like Gecko) Chrome/46.0.2490.86 Safari/537.45", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.150 Safari/537.36", "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/61.0.3163.102 Safari/537.36", "Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/45.0.2419.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Chrome/36.0.1985.125 CrossBrowser/36.0.1985.138 Safari/537.36", "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1204.0 Safari/537.1", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/51.0.2700.0 Safari/537.36#", "Mozilla/5.0 (Windows NT 10.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/45.0.2454.101 Safari/537.36", "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/533.16 (KHTML, like Gecko) Chrome/5.0.335.0 Safari/533.16", "Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.68 Safari/537.36", "Mozilla/5.0 (Windows; U; Windows 95) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.43 Safari/535.1", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/51.0.2700.0 Safari/537.36#", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.114 Safari/537.36", "Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/530.6 (KHTML, like Gecko) Chrome/2.0.174.0 Safari/530.6", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/538 (KHTML, like Gecko) Chrome/36 Safari/538", "Mozilla/5.0 (Windows; U; Windows 95) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.43 Safari/535.1", "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.18 Safari/535.1", "Mozilla/5.0 (X11; Linux x86_64; 6.1) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/17.0.1410.63 Safari/537.31", "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/49.0.2583.0 Safari/537.36", "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2151.2 Safari/537.36", "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.18 Safari/535.1", "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/536.36 (KHTML, like Gecko) Chrome/67.2.3.4 Safari/536.36", "Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/530.5 (KHTML, like Gecko) Chrome/2.0.172.0 Safari/530.5", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.69 Safari/537.36", "Mozilla/5.0 (Windows NT 10.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/45.0.2454.101 Safari/537.36", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.81 Safari/537.36", "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.111 Safari/537.36 EdgA/41.0.0.1662", "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.1"]

def login(token, log:bool=False):
    """
    Login to selfcord/discord api.

    Parameters:
        - token: User token.
    """

    global __usertoken, __baseheaders, __logging, __baseurl, __userAgents
    __baseurl = "https://discord.com/api/v9/"
    __logging = False

    if log:
        print("[SELFCORD] Logging into Selfcord...")
        __logging = True

    __usertoken = token
    Wrapper.setup(token=__usertoken, baseUrl=__baseurl, userAgent=random.choice(__userAgents), logging=__logging)
    if __logging:
        print("[SELFCORD] Updated user token to " + __usertoken + ".")
    if __logging:
        print("[SELFCORD] Setup wrapper with base url and user token.")            
    __baseheaders = {"Authorization": __usertoken, "Content-Type": "application/json"}
    if __logging:
        print("[SELFCORD] Updated base headers with new user token.")
    if __logging:
        print("[SELFCORD] Successfully logged into Selfcord.")

def logout():
    """
    Logout of selfcord/discord api.
    """

    global __usertoken, __baseheaders, __logging
    __usertoken = ""
    __baseheaders = {"Authorization": __usertoken, "Content-Type": "application/json"}

    if __logging:
        print("[SELFCORD] Logged out of Selfcord.")
    __logging = False


"""
COPYRIGHT BENNY 2021

ALL RIGHTS RESERVED TO THE 
DEVELOPER OF THIS PROJECT.
"""

from .wrapper import Wrapper
from .utils import TokenInfo, Logger

class Account:
    def comingSoon():
        Logger.log(f"Account stuff coming soon.")
        return "coming soon"


"""
COPYRIGHT BENNY 2021

ALL RIGHTS RESERVED TO THE 
DEVELOPER OF THIS PROJECT.
"""

from .wrapper import Wrapper
from .utils import TokenInfo, Logger

class User:

    def sendFriendRequest(user):
        """
        Sends a user a friend request.

        Parameters:
            - user: The user's username and discriminator.
        """

        if "#" in user:
            url = "users/@me/relationships"
            payload = {"username": user.split("#")[0], "discriminator": int(user.split("#")[1])}
        else:
            url = "users/@me/relationships/"+user
            payload = {}
        
        Logger.log(f"Sent a friend request.")
        return Wrapper.sendDiscordRequest(method="put", urlAddon=url, headers={}, payload=payload)

    def acceptFriendRequest(userId):
        """
        Accept a user's friend request.
        You must give the ID of the user.

        Parameters:
            - userId: The user's user ID.
        """

        url = "users/@me/relationships/"+userId
        payload = {}
        Logger.log(f"Accepted a friend request.")
        return Wrapper.sendDiscordRequest(method="put", urlAddon=url, headers={}, payload=payload)

    def blockUser(userId):
        """
        Blocks a user/
        You must give the ID of the user.

        Parameters:
            - userId: The user's user ID.
        """

        url = "users/@me/relationships/"+userId
        payload = {"type": 2}
        Logger.log("Blocked a user.")
        return Wrapper.sendDiscordRequest(method="put", urlAddon=url, headers={}, payload=payload)

    def setUsername(username, password):
        """
        Set your username to something new.

        Parameters:
            - username: The new username.
            - password: Your current password.
        """

        url = "users/@me"
        payload = {"username": username, "password": password}
        Logger.log("Changed username.")
        return Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload=payload)

    def setEmail(email, password):
        """
        Set your email to something new.

        Parameters:
            - email: The new email.
            - password: Your current password.            
        """

        url = "users/@me"
        payload = {"email": email, "password": password}
        Logger.log("Changed email.")
        return Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload=payload)  

    def setPassword(newPassword, password):
        """
        Set your password to something new.

        Parameters:
            - newPassword: The new password.
            - password: Your current password.
        """    

        url = "users/@me"
        payload = {"password": password, "new_password": newPassword}
        Logger.log("Changed password.")
        return Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload=payload)

    def setAboutMe(text):
        """
        Set your about me text.

        Parameters:
            - text: The about me text.
        """

        url = "users/@me"
        payload = {"bio": text}
        Logger.log("Changed about me.")
        return Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload=payload) 

    def setCustomStatus(text):
        """
        Set your custom status text.

        Parameters:
            - text: The custom status text.
            - emoji: The custom status emoji.
        """

        url = "users/@me/settings"
        payload = {"custom_status": {"text": text}}
        Logger.log("Changed custom status.")
        return Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload=payload) 

    def setTheme(theme):
        """
        Change your discord client theme.

        Parameters:
            - theme: The client theme, dark or light.
        """

        url = "users/@me/settings"
        payload = {"theme": theme.lower()}
        Logger.log("Changed discord client theme.")
        return Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload=payload)                     

    def getUsername():
        """
        Gets the username of the logged in account.
        """

        url = "users/@me"
        request = Wrapper.sendDiscordRequest(method="get", urlAddon=url, headers={}, payload={})
        Logger.log("Returned fetched username.")
        return request.json()["username"]

    def getDiscriminator():
        """
        Gets the discriminator of the logged in account.
        """

        url = "users/@me"
        request = Wrapper.sendDiscordRequest(method="get", urlAddon=url, headers={}, payload={})
        Logger.log("Returned fetched discriminator.")
        return request.json()["disciminator"]       

    def getId():
        """
        Gets the id of the logged in account.
        """

        url = "users/@me"
        request = Wrapper.sendDiscordRequest(method="get", urlAddon=url, headers={}, payload={})
        Logger.log("Returned fetched id.")
        return request.json()["id"]       

    def getAvatar():
        """
        Gets the avatar of the logged in account.
        """

        url = "users/@me"
        request = Wrapper.sendDiscordRequest(method="get", urlAddon=url, headers={}, payload={})
        Logger.log("Returned fetched avatar.")
        return request.json()["avatar"] 

    def getFriends():
        """
        Gets the friends of the logged in account.
        """

        friends = []
        request = Wrapper.sendDiscordRequest("get", "users/@me/relationships", headers={}, payload={})
        Logger.log("Fetched friends.")
        for item in request.json():
            if item["type"] == 1:
                Logger.log("Appended friend to new list.")
                friends.append({"username": item["user"]["username"], "id": item["user"]["id"], "avatar": item["user"]["avatar"], "discriminator": item["user"]["discriminator"], "public_flags": item["user"]["public_flags"]})

        Logger.log("Returned a list of friends.")
        return friends              


from .wrapper import Wrapper
from .utils import TokenInfo, Logger
from .selfcord import Message

class Channel:
    def __init__(self, id):
        request = Wrapper.sendDiscordRequest(method="get", urlAddon=f"channels/{id}", headers={}, payload={}).json()
        self.id = id
        self.name = request["name"]
        self.topic = request["topic"]
        self.guild = request["guild_id"]
        self.type = request["type"]
    def send(self, message=None, embed=None):
        data = {}
        url = "channels/"+str(self.id)+"/messages"
        if message != None:
            data["content"] = message
        if embed != None:
            data["embed"] = embed

        request = Wrapper.sendDiscordRequest(method="post", urlAddon=url, headers={}, payload=data).json()
        return Message(request["id"], request["content"], request["embeds"], request["channel_id"], request["author"])


import requests
from .wrapper import Wrapper
from .utils import TokenInfo, Logger
from .selfcord import Channel

class Message:
    def __init__(self, id, content, embed, channelId, author):
        self.id = id
        self.content = content
        self.channel = Channel(channelId)
        self.embed = embed
        self.author = author
    def edit(self, content=None, embed=None):
        url = "channels/"+str(self.channel.id)+"/messages/"+str(self.id)
        request = Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload={"content": content, "embed": embed}).json()
        return Message(request["id"], request["content"], request["embeds"], request["channel_id"], request["author"])        


"""
COPYRIGHT BENNY 2021

ALL RIGHTS RESERVED TO THE 
DEVELOPER OF THIS PROJECT.
"""

from .wrapper import Wrapper

class Logger:
    def log(message):
        if Wrapper.getLogging():
            print(f"[SELFCORD] {message}")   
        else:
            return   

class TokenInfo:
    def getUsername(token):
        """
        Get the username of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched username from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me", headers={}, payload={}, token=token).json()["username"]

    def getId(token):
        """
        Get the ID of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched id from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me", headers={}, payload={}, token=token).json()["id"]  

    def getDiscriminator(token):
        """
        Get the discriminator of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched discriminator from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me", headers={}, payload={}, token=token).json()["discriminator"]
        
    def getAvatar(token):
        """
        Get the avatar of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched avatar from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me", headers={}, payload={}, token=token).json()["avatar"]                              

    def getEmail(token):
        """
        Get the email of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched email from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me", headers={}, payload={}, token=token).json()["email"]

    def getBanner(token):
        """
        Get the banner of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched banner from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me", headers={}, payload={}, token=token).json()["banner"]

    def getBio(token):
        """
        Get the bio of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched bio from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me", headers={}, payload={}, token=token).json()["bio"]

    def getCustomStatusText(token):
        """
        Get the custom status text of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched custom status text from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me/settings", headers={}, payload={}, token=token).json()["custom_status"]["text"]

    def getCustomStatusEmoji(token):
        """
        Get the custom status emoji of a token.

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched custom status emoji from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me/settings", headers={}, payload={}, token=token).json()["custom_status"]["emoji_name"]

    def getStatus(token):
        """
        Get the status of a token.
        Online,Idle,DND,Invisible

        Parameters:
            - token: The account token.
        """

        Logger.log(f"Returned fetched status from `{token}`.")
        return Wrapper.sendDiscordRequestCustomToken("get", "users/@me/settings", headers={}, payload={}, token=token).json()["status"]

    def getFriends(token):
        """
        Get a list of friends from the token.

        Parameters:
            - token: The account token.
        """

        friends = []
        request = Wrapper.sendDiscordRequestCustomToken("get", "users/@me/relationships", headers={}, payload={}, token=token)
        Logger.log(f"Fetched friends from `{token}`.")
        for item in request.json():
            if item["type"] == 1:
                Logger.log("Appended friend to new list.")
                friends.append({"username": item["user"]["username"], "id": item["user"]["id"], "avatar": item["user"]["avatar"], "discriminator": item["user"]["discriminator"], "public_flags": item["user"]["public_flags"]})

        Logger.log("Returned a list of friends.")
        return friends     


class Embed:
    def __init__(self, title, description="", colour="", url=""):
        self.embed = {"title": title, "description": description, "color": colour, "fields": []}
    def read(self):
        return self.embed
    def set_footer(self, text, icon_url=""):
        self.embed.update({"footer": {"icon_url": icon_url, "text": text}})
    def set_image(self, url):
        self.embed.update({"image": {"url": url}})
    def set_thumbnail(self, url):
        self.embed.update({"thumbnail": {"url": url}})
    def set_author(self, name, url="", icon_url=""):
        self.embed.update({"author": {"name": name, "url": url, "icon_url": icon_url}})
    def add_field(self, name, value, inline=False):
        self.embed["fields"].append({"name": name, "value": value, "inline": inline})
    


"""
COPYRIGHT BENNY 2021

ALL RIGHTS RESERVED TO THE 
DEVELOPER OF THIS PROJECT.
"""

from .wrapper import Wrapper
from .utils import TokenInfo, Logger

class Messages:

    def sendMessage(channelId, message=None, embed=None):
        """
        Send a message to channel.

        Parameters:
            - message: The message content.
            - channelId: The channel's ID.
        """

        data = {}
        url = "channels/"+str(channelId)+"/messages"
        if message != None:
            data["content"] = message
        if embed != None:
            data["embed"] = embed

        Logger.log(f"Sent '{message}' to '{channelId}'.")
        return Wrapper.sendDiscordRequest(method="post", urlAddon=url, headers={}, payload=data)

    def editMessage(messageId, newMessage, channelId):
        """
        Edit a message in a channel.

        Parameters:
            - messageId: The message's ID.
            - channelId: The channel's ID.
        """

        url = "channels/"+str(channelId)+"/messages/"+str(messageId)
        Logger.log(f"Edited '{messageId}' content to be '{newMessage}' in '{channelId}'.")
        return Wrapper.sendDiscordRequest(method="patch", urlAddon=url, headers={}, payload={"content": newMessage})

    def deleteMessage(messageId, channelId):
        """
        Delete a message from a channel.

        Parameters:
            - messageId: The message's ID.
            - channelId: The channel's ID.
        """

        url = "channels/"+str(channelId)+"/messages/"+str(messageId)
        Logger.log(f"Deleted '{messageId}' in '{channelId}'.")
        return Wrapper.sendDiscordRequest(method="delete", urlAddon=url, headers={}, payload={})


"""
Selfcord
~~~~~~~~

A discord.py addon for selfbots in mind.  

© Benny 2021

"""

from .selfcord import *
from .channel2 import *
from .message2 import *
from .wrapper import *
from .utils import *
from .embed import *
from .user import *
from .userinfo import *
from .messages import *
from .account import *


"""
COPYRIGHT BENNY 2021

ALL RIGHTS RESERVED TO THE 
DEVELOPER OF THIS PROJECT.
"""

from .wrapper import Wrapper
from .utils import TokenInfo, Logger

class UserInfo:

    def getUsername(id):
        """
        Get the username from an id.

        Parameters:
            - id: The users id.
        """

        Logger.log(f"Returned fetched username from '{id}'.")
        return Wrapper.sendDiscordRequest(method="get", urlAddon=f"users/{id}", headers={}, payload={}).json()["username"]

    def getId(id):
        """
        Get the id from an id.

        Parameters:
            - id: The users id.
        """

        Logger.log(f"Returned fetched id from '{id}'.")
        return Wrapper.sendDiscordRequest(method="get", urlAddon=f"users/{id}", headers={}, payload={}).json()["id"]

    def getAvatar(id):
        """
        Get the avatar from an id.

        Parameters:
            - id: The users id.
        """

        Logger.log(f"Returned fetched avatar from '{id}'.")
        return Wrapper.sendDiscordRequest(method="get", urlAddon=f"users/{id}", headers={}, payload={}).json()["avatar"]

    def getBanner(id):
        """
        Get the banner from an id.

        Parameters:
            - id: The users id.
        """

        Logger.log(f"Returned fetched banner from '{id}'.")
        return Wrapper.sendDiscordRequest(method="get", urlAddon=f"users/{id}", headers={}, payload={}).json()["banner"]

    def getDiscriminator(id):
        """
        Get the discriminator from an id.

        Parameters:
            - id: The users id.
        """

        Logger.log(f"Returned fetched discriminator from '{id}'.")
        return Wrapper.sendDiscordRequest(method="get", urlAddon=f"users/{id}", headers={}, payload={}).json()["discriminator"]     

    def getPublicFlags(id):
        """
        Get the public flags from an id.

        Parameters:
            - id: The users id.
        """

        Logger.log(f"Returned fetched public flags from '{id}'.")
        return Wrapper.sendDiscordRequest(method="get", urlAddon=f"users/{id}", headers={}, payload={}).json()["public_flags"]         

    def isBot(id):
        """
        Is the id a bot

        Parameters:
            - id: The users id.
        """

        Logger.log(f"Returned fetched bot from '{id}'.")
        return Wrapper.sendDiscordRequest(method="get", urlAddon=f"users/{id}", headers={}, payload={}).json()["bot"]                   


"""
COPYRIGHT BENNY 2021

ALL RIGHTS RESERVED TO THE 
DEVELOPER OF THIS PROJECT.
"""

import requests
import json

__baseUrl = ""
__userToken = ""
__userAgent = ""
__logging = None

class Wrapper:
    def setup(token, baseUrl, userAgent, logging):
        global __userToken, __baseUrl, __userAgent, __logging
        __baseUrl = baseUrl
        __userToken = token
        __userAgent = userAgent
        __logging = logging

    def sendRequest(method, url, headers, payload):
        return requests.request(method=method, url=url, headers=headers, data=str(payload))
    def sendDiscordRequestCustomToken(method, urlAddon, headers, payload, token):
        headers["Authorization"] = token;headers["Content-Type"] = "application/json";headers["User-Agent"] = __userAgent
        if __logging:
            print(json.dumps(headers))
        if method.lower() == "get":
            request = requests.get(__baseUrl + urlAddon, headers=headers)
        else:
            request = requests.request(method, __baseUrl + urlAddon, headers=headers, data=json.dumps(payload))
        return request        
    def sendDiscordRequest(method, urlAddon, headers, payload):
        headers["Authorization"] = __userToken;headers["Content-Type"] = "application/json";headers["User-Agent"] = __userAgent
        if __logging:
            print(json.dumps(headers))        
        if method.lower() == "get":
            request = requests.get(__baseUrl + urlAddon, headers=headers)
        else:
            request = requests.request(method, __baseUrl + urlAddon, headers=headers, data=json.dumps(payload))
        return request
    def getBaseUrl():
        global __baseUrl
        return __baseUrl
    def getUserToken():
        global __userToken
        return __userToken
    def getUserAgent():
        global __userAgent
        return __userAgent
    def getLogging():
        global __logging
        return __logging


from setuptools import setup
import re

requirements = ["requests"]
version = '0.1.8'
readme = open('README.md').read()
extras_require = {}

setup (
        name='selfcord',
        author='Benny',
        url='https://github.com/ilyBenny/selfcord',
        project_urls={},
        version=version,
        packages=['selfcord'],
        license='MIT',
        description='The best Discord selfbot API wrapper.',
        long_description=readme,
        long_description_content_type="text/markdown",
        include_package_data=True,
        install_requires=requirements,
        extras_require=extras_require,
        python_requires='>=3.8.0',
        classifiers=[
          'Development Status :: 5 - Production/Stable',
          'License :: OSI Approved :: MIT License',
          'Intended Audience :: Developers',
          'Natural Language :: English',
          'Operating System :: OS Independent',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9',
          'Topic :: Internet',
          'Topic :: Software Development :: Libraries',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Topic :: Utilities',
        ]
      )
